DaiControl

Struct DaiControl 

pub struct DaiControl { /* private fields */ }
Control that connects the Audio start / stop to a Digital Audio Interface device, which is added to an AudioCore configured Fuchsia Audio system. The DAI driver provides the ring buffer and is connected to the controller, providing audio without encoding in-band. This Control cannot start audio without a call in progress.

Implementations

Source

impl DaiControl

pub async fn discover(proxy: AudioDeviceEnumeratorProxy) -> Result<Self, Error>

pub fn build( audio_core: AudioDeviceEnumeratorProxy, input: DaiAudioDevice, output: DaiAudioDevice, ) -> Self