pub struct Number(/* private fields */);Expand description
A phone number. Clients should generally use as_non_at_string and
from_non_at_string to work with these, which add and remove delimiting
quotes. As AT commands require these quotes to be in place around numbers,
when generating and parsing AT commands, clients should use from_at_string
and as_at_string, which maintain the quotes.
Implementations
Sourceimpl Number
impl Number
Sourcepub fn type_(&self) -> i64
pub fn type_(&self) -> i64
Returns the numeric representation of the Number’s format as specified in HFP v1.8, Section 4.34.2.
Sourcepub fn to_non_at_string(&self) -> String
pub fn to_non_at_string(&self) -> String
Converts the Number to a String, stripping quotes from the beginning and end.
Sourcepub fn to_at_string(&self) -> String
pub fn to_at_string(&self) -> String
Converts the Number to a String to be used in AT commands, leaving the delimiting quotes in place.
Sourcepub fn from_non_at_string(s: &str) -> Self
pub fn from_non_at_string(s: &str) -> Self
Converts a String to a Number, adding delimiting quotes.
Sourcepub fn from_at_string(s: &str) -> Self
pub fn from_at_string(s: &str) -> Self
Converts a String to a Number, from an AT command, leaving the delimiting quotes in place.